[英語（English）](./README.md)
# Auraboros
自分の開発用のために作られた、pygameを核にしたゲームフレームワークです。
8trailのソースコードを流用・改変し、再利用できるようにしたものが基になっています。

# how to install
```
pip install auraboros
```

# how to use CLI
```
python -m auraboros 
```